<?php

namespace Drupal\address_md\EventSubscriber;

use Drupal\address\Event\AddressEvents;
use Drupal\address\Event\AddressFormatEvent;
use Drupal\Core\StringTranslation\StringTranslationTrait;
use CommerceGuys\Addressing\AddressFormat\AdministrativeAreaType;
use Symfony\Component\EventDispatcher\EventSubscriberInterface;

/**
 * Class AddressEventsSubscriber.
 *
 * @package Drupal\custom_events\EventSubscriber
 */
class AddressEventsSubscriber implements EventSubscriberInterface {

  use StringTranslationTrait;

  /**
   * {@inheritdoc}
   */
  public static function getSubscribedEvents() {
    $events[AddressEvents::ADDRESS_FORMAT][] = ['onAddressFormat'];
    return $events;
  }

  /**
   * Alters the address format for Rep. of Moldova.
   *
   * @param \Drupal\address\Event\AddressFormatEvent $event
   *   The address format event.
   */
  public function onAddressFormat(AddressFormatEvent $event) {
    $definition = $event->getDefinition();

    if (isset($definition['country_code']) && $definition['country_code'] == 'MD') {
      $definition['format'] = "%givenName %familyName\n%organization\n%administrativeArea-%locality\n%dependentLocality\n%postalCode\n%addressLine1\n%addressLine2";
      $definition['subdivision_depth'] = 2;
      $definition['administrative_area_type'] = AdministrativeAreaType::DISTRICT;
      $event->setDefinition($definition);
    }
  }

}
